# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

* Added support for GMP 20.08 [#254](https://github.com/greenbone/python-gvm/pull/254)

### Changed

* Refactored Gmp classes into mixins [#254](https://github.com/greenbone/python-gvm/pull/254)

### Fixed

* Require method and condition arguments for modify_alert with an event [#267](https://github.com/greenbone/python-gvm/pull/267)

[Unreleased]: https://github.com/greenbone/python-gvm/compare/v1.6.0...main

## [1.6.0] - 2020-06-10

### Added

* Extend AliveTest and ScannerType enums.
  [#235](https://github.com/greenbone/python-gvm/pull/235)

### Fixed

* Fix python-gvm v8/v9 type checks. [#244](https://github.com/greenbone/python-gvm/pull/244)

[1.6.0]: https://github.com/greenbone/python-gvm/compare/v1.5.0...v1.6.0

